pw_null

Macro pw_null 

macro_rules! pw_null {
    ($prog: ident, $b: block) => { ... };
}
Internal helper macro for the code generator. It creates a ProgWriter instance from the given code block. pw_null is used in cases where there are only side effects and no return values to be stored anywhere. $prog is the variable of the Prog.