pw_provides_result_pos

Macro pw_provides_result_pos 

macro_rules! pw_provides_result_pos {
    ($prog: ident, $b: block) => { ... };
}
Internal helper macro for the code generator. It creates a ProgWriter instance from the given code block. It’s used in cases where the ProgWriter code in the code block $b defines the storage position where it wrote the results to. The calling parent then has to take care to store the value in some reasonable place or not store it at all. $prog is the variable of the Prog.