NVec

Enum NVec 

pub enum NVec<N: NVecNum> {
    Vec2(N, N),
    Vec3(N, N, N),
    Vec4(N, N, N, N),
}
WLambda supports Integer and Float vectors in two, three, and four dimensions. See also VVal::nvec and functions like VVal::ivec2, VVal::fvec2, …

Variants



Vec2(N, N)



Vec3(N, N, N)



Vec4(N, N, N, N)

Implementations

Source

impl<N: NVecNum> NVec<N>

pub fn x(&self) -> VVal

The x component of the number vector as VVal.

pub fn x_raw(&self) -> N

The x component of the number vector as faw integer/float type.

pub fn y(&self) -> VVal

The y component of the number vector as VVal.

pub fn y_raw(&self) -> N

The y component of the number vector as faw integer/float type.

pub fn z(&self) -> Option<VVal>

The z component of the number vector as VVal.

pub fn z_raw(&self) -> Option<N>

The z component of the number vector as faw integer/float type.

pub fn w(&self) -> Option<VVal>

The w component of the number vector as VVal.

pub fn w_raw(&self) -> Option<N>

The w component of the number vector as faw integer/float type.

pub fn dims(&self) -> NVecDim

Returns the dimensionality of this number vector.

pub fn into_tpl(self) -> (N, N, Option<N>, Option<N>)

Convert this numeric vector into a tuple of raw integer/float types. All vectors contain x and y components. The z and w components are optional.

pub fn into_zero_tpl(self) -> (N, N, N, N)

A tuple of four elements representing the components of this vector. If a component wasn’t available, a 0 takes its place.

pub fn into_vval_tpl(self) -> (VVal, VVal, Option<VVal>, Option<VVal>)

Convert this numeric vector into a tuple of VVal. All vectors contain x and y components. The z and w components are optional.

pub fn from_tpl(tpl: (N, N, Option<N>, Option<N>)) -> Option<Self>

Convert a tuple of raw integer/float types into an NVec.

pub fn from_vval_tpl<W: AsRef<VVal>>( (x, y, z, w): (W, W, Option<W>, Option<W>), ) -> Option<Self>

Convert a tuple of VVal into an NVec.

pub fn s(&self) -> String

Returns a string representation of this numeric vector.

pub fn vec2(self) -> Self

Converts this vector into one with three dimensions, discarding the unnecessary values.

pub fn vec3(self) -> Self

Converts this vector into one with three dimensions, discarding the unnecessary values and filling in the missing values with 0s if necessary.

pub fn vec4(self) -> Self

Converts this vector into one with four dimensions, filling in the missing values with 0s if necessary.

pub fn mag2(&self) -> f64

Returns the squared magnitude of this vector like x^2 + y^2. See also NVec::mag.

pub fn mag(&self) -> f64

Returns the magnitude of this vector also known as the mathematical length of the vector: sqrt(x^2 + y^2) for instance for a 2 dimensional vector.

pub fn norm(self) -> Self

Convert this NVec into a normalized (unit length) vector.

pub fn dot(self, o: NVec<N>) -> N

Calculates the dot product of two numerical vectors.

pub fn cross(self, o: NVec<N>) -> Self

Calculates the cross product of two numerical vectors.

pub fn lerp(self, o: NVec<N>, t: f64) -> Self

Linear interpolation from this vector to the given vector \a o. The parameter \a t should be between 0.0 and 1.0.

pub fn vec2rad(self) -> f64

Turns the first two components of this vector into an angle in radians.

pub fn rad2vec(f: f64) -> Self

Produces a Vec2 based on the radians provided to this function as a float.

pub fn slerp(self, o: NVec<N>, t: f64) -> Self

The resulting NVec will almost always have a length of 1, except for in cases where o and self are collinear opposites. To work around this, the resulting vector may be normalized.

Panics

Panics if input vectors aren’t unit vectors.