wlambda

Module selector

Implements a data querying algorithm that is used by the WLambda $S(...) syntax and by WLambda std:selector. It’s a recursive searching, matching and capturing algorithm.

Enums

Functions

  • Creates a function that takes a string slice and tries to find the compiled regular expression in it. The returned function then returns a PatResult which stores the captures and whether the pattern matched.
  • Creates a function that takes a string slice and tries to find the compiled regular expression in it. The returned function then returns a PatResult which stores the captures and whether the pattern matched.
  • Creates a WLambda function that takes a string slice and tries to find the compiled regular expression in it. The returned function then returns a PatResult which stores the captures and whether the pattern matched.
  • Creates a function that takes a VVal data structure and runs the given selector expression on it. The returned function then returns a list of captured nodes or $none if nothing was found.
  • Creates a WLambda function that takes a VVal data structure and runs the given selector expression on it. The returned function then returns a list of captured nodes or $none if nothing was found.
  • Parses a regex pattern from a parser State and returns the VVal data structure describing the parsed pattern.

Type Aliases