create_regex_find_function

Function create_regex_find_function 

pub fn create_regex_find_function(
    pat: &str,
    result_ref: VVal,
    mode: RegexMode,
) -> Result<VVal, ParseError>
Creates a WLambda function that takes a string slice and tries to find the compiled regular expression in it. The returned function then returns a PatResult which stores the captures and whether the pattern matched.