create_selector

Function create_selector 

pub fn create_selector(
    sel: &str,
    result_ref: VVal,
) -> Result<Box<dyn Fn(&VVal) -> VVal>, ParseError>
Creates a function that takes a VVal data structure and runs the given selector expression on it. The returned function then returns a list of captured nodes or $none if nothing was found.