pub fn parse_pattern(ps: &mut State) -> Result<VVal, ParseError>Expand description
Parses a regex pattern from a parser State and returns the VVal data structure describing the parsed pattern.
pub fn parse_pattern(ps: &mut State) -> Result<VVal, ParseError>Parses a regex pattern from a parser State and returns the VVal data structure describing the parsed pattern.