[][src]Module wlambda::threads

This module provides threading functionality for WLambda. It does not depend on anything else than the Rust standard library.

If you want to implement or specialize thread creation please refer to the documentation of the ThreadCreator trait.

Structs

AValChannel
AtomicAVal

WLambda:

AtomicAValSlot
AtomicValSlot
DefaultThreadCreator

Default implementation of a ThreadCreator.

ForkSenderError
FunctionGlobalEnvCreator

This is an easy way to provide a GlobalEnv creation function to the DefaultThreadCreator.

Enums

AVal

AVal is a copy-by-value structure for storing the most important data of VVals inside an atomic container (AtomicAVal).

Traits

ThreadCreator

This trait allows WLambda to create new threads. You can either use the DefaultThreadCreator default implementation or provide your own. Providing your own might be necessary if you want to customize how a thread is created.

ThreadGlobalEnvCreator

This trait handles creation of the GlobalEnv for new threads. You can reuse the DefaultThreadCreator by just providing it a custom ThreadGlobalEnvCreator implementation. This suffices in most cases where you want to embed WLambda and provide a custom API to new threads.

ThreadSafeUsr