Module util

Module util 

Implements utilitiy functions that are used by the WLambda standard library. For instance a SplitMix64 random number generator.

Structs

FnvHasher
Original FNV Rust implementation taken from fnv crate on crates.io by Alex Crichton alex@alexcrichton.com under Apache-2.0 / MIT license Copyright 2018.
SplitMix64
The SplitMix64 random number generator.

Functions

edit_distance
Returns the edit distance between strings a and b.
hex2hsvaf
hex2rgba
hex2rgbaf
hsv2rgb
hsva2hexf
hsva2rgba
now_timestamp
rand_closed_open01
rand_full_i
rand_i
rgb2hsv
rgba2hex
rgba2hexf
rgba2hsvaf
srand
u64_to_closed_open01
u64_to_open01
u64_to_open_closed01