wlambda

Module vval

This module provides the core data structures used by the parser, compiler and evaluator of WLambda.

Structs

Enums

  • This type gives the end where to add the VVal::add function.
  • Encodes all kinds of jumps up the call stack, like break and next in Loops.
  • Encodes the different types of AST nodes.
  • Describes an action that needs to be done when returning from a function or somehow jumps unpredictably around the VM prog.
  • VVal aka. VariantValue is a data structure to represent all kinds of WLambda data structures.
  • The internal distinction between a character and a byte. They share parts of the lexical represenation and also the semantic purspose is similar.
  • Position of a variable represented in the CompileEnv.

Traits

  • You can implement your own VVal data type and provide it via global functions:

Functions

Type Aliases