[][src]Module wlambda::compiler

Structs

GlobalEnv

Holds global environment variables.

Functions

bench_eval_ast

Evaluates a parsed AST a number of times and prints out some benchmarking information.

eval

Evaluates a string of WLambda code and executes it with the given GlobalEnv.

s_eval

Evaluates a string of WLambda code, executes it and returns a string representation of the VVal.

Type Definitions

GlobalEnvRef

Reference type of GlobalEnv.