[−][src]Module wlambda::threads
This module provides threading functionality for WLambda. It does not depend on anything else than the Rust standard library.
If you want to implement or specialize thread creation please
refer to the documentation of the ThreadCreator trait.
Structs
| AValChannel | |
| AtomicAVal | WLambda: |
| AtomicAValSlot | |
| AtomicValSlot | |
| DefaultThreadCreator | Default implementation of a ThreadCreator. |
| ForkSenderError | |
| FunctionGlobalEnvCreator | This is an easy way to provide a |
Enums
| AVal | AVal is a copy-by-value structure for storing the most important data of VVals inside an atomic container (AtomicAVal). |
Traits
| ThreadCreator | This trait allows WLambda to create new threads.
You can either use the |
| ThreadGlobalEnvCreator | This trait handles creation of the GlobalEnv for new
threads. You can reuse the |
| ThreadSafeUsr |