Implements utilitiy functions that are used by the WLambda standard library. For instance a SplitMix64 random number generator.
Structs
- FnvHasher
- Original FNV Rust implementation taken from fnv crate on crates.io by Alex Crichton alex@alexcrichton.com under Apache-2.0 / MIT license Copyright 2018.
- Split
Mix64 - The
SplitMix64random number generator.