[−][src]Module wlambda::vval
This module provides the core data structures used by the parser, compiler and evaluator of WLambda.
Structs
| CompileError | |
| DropFun | Handles calling of destructor functions. |
| Env | The runtime environment of the evaluator. |
| FileRef | |
| LoopInfo | |
| Stdio | |
| SynPos | Structure for holding information about origin of an AST node. |
| SynPosInfo | |
| VValFun | This structure is the runtime representation of a WLambda function value. |
Enums
| CollectionAdd | This type gives the end where to add the |
| FunType | |
| StackAction | Encodes all kinds of jumps up the call stack, like |
| Syntax | Encodes the different types of AST nodes. |
| UnwindAction | Describes an action that needs to be done when returning from a function or somehow jumps unpredictably around the VM prog. |
| VVal | VVal aka. VariantValue is a data structure to represent all kinds of WLambda data structures. |
| VValChr | The internal distinction between a character and a byte. They share parts of the lexical represenation and also the semantic purspose is similar. |
| VarPos | Position of a variable represented in the |
Traits
| VValUserData | You can implement your own VVal data type and provide it via global functions: |
Functions
| format_escape_char | |
| format_vval_byt | |
| format_vval_str |
Type Definitions
| ClosNodeRef | |
| EvalNode | |
| VValIter |