[−][src]Module wlambda::vval
This module provides the core data structures used by the parser, compiler and evaluator of WLambda.
Structs
| CompileError | |
| DropVVal | Handles calling of destructor functions. |
| Env | The runtime environment of the evaluator. |
| FileRef | |
| SynPos | Structure for holding information about origin of an AST node. |
| VValFun | This structure is the runtime representation of a WLambda function value. |
Enums
| StackAction | Encodes all kinds of jumps up the call stack, like |
| Syntax | Encodes the different types of AST nodes. |
| VVal | VVal aka. VariantValue is a data structure to represent all kinds of WLambda data structures. |
Traits
| VValUserData | You can implement your own VVal data type and provide it via global functions: |
Functions
| format_vval_byt | |
| format_vval_str |
Type Definitions
| ClosNodeRef | |
| EvalNode |